Class: Strava::Models::Destination

Inherits:
Response show all
Defined in:
lib/strava/models/destination.rb

Overview

Note:

This model is not documented by Strava API documentation. Properties are inferred from API responses.

Represents a destination or link reference.

Used to provide navigation links to related resources or pages. This model is not documented in the official Strava API reference.

Examples:

Accessing destination information

# From XOMs or local legend data
if xoms.destination
  puts "Name: #{xoms.destination.name}"
  puts "Type: #{xoms.destination.type}"
  puts "Link: #{xoms.destination.href}"
end

See Also:

Instance Method Summary collapse

Instance Method Details

#hrefString?

Note:

Not documented by Strava API

Returns URL or path to the destination resource.

Returns:

  • (String, nil)

    URL or path to the destination resource



28
# File 'lib/strava/models/destination.rb', line 28

property 'href'

#nameString?

Note:

Not documented by Strava API

Returns Display name of the destination.

Returns:

  • (String, nil)

    Display name of the destination



36
# File 'lib/strava/models/destination.rb', line 36

property 'name'

#typeString?

Note:

Not documented by Strava API

Returns Type of destination (e.g., "segment").

Returns:

  • (String, nil)

    Type of destination (e.g., "segment")



32
# File 'lib/strava/models/destination.rb', line 32

property 'type'