Class: Strava::Models::Kudoser

Inherits:
Response show all
Defined in:
lib/strava/models/kudoser.rb

Overview

Note:

This model is not documented by Strava API documentation. Properties are inferred from API responses.

Represents a user who gave kudos to an activity.

Kudos are a way for athletes to show appreciation for each other's activities. This model is not documented in the official Strava API reference.

Examples:

Listing kudos for an activity

kudos = client.activity_kudos(1234567890)
kudos.each do |kudoser|
  puts "#{kudoser.display_name} gave kudos"
  puts "  Avatar: #{kudoser.avatar_url}"
end

See Also:

  • Api::Client#activity_kudos

Instance Method Summary collapse

Instance Method Details

#avatar_urlString?

Note:

Not documented by Strava API

Returns URL to the athlete's avatar image.

Returns:

  • (String, nil)

    URL to the athlete's avatar image



34
# File 'lib/strava/models/kudoser.rb', line 34

property 'avatar_url'

#destination_urlString?

Note:

Not documented by Strava API

Returns URL to the athlete's profile page.

Returns:

  • (String, nil)

    URL to the athlete's profile page



26
# File 'lib/strava/models/kudoser.rb', line 26

property 'destination_url'

#display_nameString?

Note:

Not documented by Strava API

Returns Display name of the athlete who gave kudos.

Returns:

  • (String, nil)

    Display name of the athlete who gave kudos



30
# File 'lib/strava/models/kudoser.rb', line 30

property 'display_name'

#show_nameBoolean?

Note:

Not documented by Strava API

Returns Whether to show the athlete's name.

Returns:

  • (Boolean, nil)

    Whether to show the athlete's name



38
# File 'lib/strava/models/kudoser.rb', line 38

property 'show_name'