Class: Strava::Models::LocalLegend

Inherits:
Response show all
Defined in:
lib/strava/models/local_legend.rb

Overview

Note:

This model is not documented by Strava API documentation. Properties are inferred from API responses.

Represents Local Legend status on a segment.

Local Legends are athletes with the most efforts on a segment in the last 90 days. This model contains information about the current local legend for a segment. This model is not documented in the official Strava API reference.

Examples:

Accessing local legend information

segment = client.segment(1234567)
if segment.local_legend
  legend = segment.local_legend
  puts "Local Legend: #{legend.title}"
  puts "Athlete ID: #{legend.athlete_id}"
  puts "#{legend.effort_description} (#{legend.effort_count} efforts)"
end

See Also:

Instance Method Summary collapse

Instance Method Details

#athlete_idInteger?

Note:

Not documented by Strava API

Returns ID of the athlete who is the local legend.

Returns:

  • (Integer, nil)

    ID of the athlete who is the local legend



29
# File 'lib/strava/models/local_legend.rb', line 29

property 'athlete_id'

#destinationDestination?

Note:

Not documented by Strava API

Returns Link to related resource.

Returns:



53
# File 'lib/strava/models/local_legend.rb', line 53

property 'destination'

#effort_countInteger?

Note:

Not documented by Strava API

Returns Number of efforts by this athlete in the qualifying period.

Returns:

  • (Integer, nil)

    Number of efforts by this athlete in the qualifying period



45
# File 'lib/strava/models/local_legend.rb', line 45

property 'effort_count'

#effort_countsHash?

Note:

Not documented by Strava API

Returns Detailed effort count data.

Returns:

  • (Hash, nil)

    Detailed effort count data



49
# File 'lib/strava/models/local_legend.rb', line 49

property 'effort_counts'

#effort_descriptionString?

Note:

Not documented by Strava API

Returns Description of the effort count (e.g., "X efforts in the last 90 days").

Returns:

  • (String, nil)

    Description of the effort count (e.g., "X efforts in the last 90 days")



41
# File 'lib/strava/models/local_legend.rb', line 41

property 'effort_description'

#profileString?

Note:

Not documented by Strava API

Returns URL to the athlete's profile picture.

Returns:

  • (String, nil)

    URL to the athlete's profile picture



37
# File 'lib/strava/models/local_legend.rb', line 37

property 'profile'

#titleString?

Note:

Not documented by Strava API

Returns Title or name of the local legend.

Returns:

  • (String, nil)

    Title or name of the local legend



33
# File 'lib/strava/models/local_legend.rb', line 33

property 'title'