Module: Strava::Models::Mixins::MovingTime
- Extended by:
- ActiveSupport::Concern
- Includes:
- TimeInHours
- Included in:
- ActivityTotal, DetailedActivity, DetailedSegmentEffort, Lap, Split, SummaryActivity
- Defined in:
- lib/strava/models/mixins/moving_time.rb
Overview
Provides moving time formatting methods.
Moving time is the time spent actually moving during an activity, excluding stopped time. This mixin adds the moving_time property and a helper method to format it as hours/minutes/seconds.
Instance Method Summary collapse
-
#moving_time_in_hours_s ⇒ String?
Returns formatted moving time as hours, minutes, and seconds.
Instance Method Details
#moving_time_in_hours_s ⇒ String?
Returns formatted moving time as hours, minutes, and seconds.
32 33 34 |
# File 'lib/strava/models/mixins/moving_time.rb', line 32 def moving_time_in_hours_s time_in_hours_s moving_time end |