Class: Strava::Models::PowerZoneRanges
- Inherits:
-
Response
- Object
- Hashie::Trash
- Strava::Model
- Response
- Strava::Models::PowerZoneRanges
- Defined in:
- lib/strava/models/power_zone_ranges.rb
Overview
Represents an athlete's power zone configuration.
Power zones define intensity levels based on watts output. These are typically used for cycling training and are often based on FTP (Functional Threshold Power).
Instance Method Summary collapse
-
#zones ⇒ Array<ZoneRange>
Array of power zone ranges in watts.