Class: Strava::Models::Xoms

Inherits:
Response show all
Defined in:
lib/strava/models/xoms.rb

Overview

Note:

This model is not documented by Strava API documentation. Properties are inferred from API responses.

Represents segment leaderboard achievements (KOM/QOM).

Contains information about King of the Mountain (KOM), Queen of the Mountain (QOM), and overall segment records. This model is not documented in the official Strava API reference.

Examples:

Accessing XOM (KOM/QOM) information

activity = client.activity(1234567890)
if activity.xoms
  puts "KOM: #{activity.xoms.kom}"
  puts "QOM: #{activity.xoms.qom}"
  puts "Overall: #{activity.xoms.overall}"
  if activity.xoms.destination
    puts "Segment: #{activity.xoms.destination.name}"
  end
end

See Also:

Instance Method Summary collapse

Instance Method Details

#destinationDestination?

Note:

Not documented by Strava API

Returns Link to the segment where this achievement was earned.

Returns:

  • (Destination, nil)

    Link to the segment where this achievement was earned



44
# File 'lib/strava/models/xoms.rb', line 44

property 'destination', transform_with: ->(v) { Strava::Models::Destination.new(v) }

#komString, ...

Note:

Not documented by Strava API

Returns King of the Mountain achievement data.

Returns:

  • (String, Integer, nil)

    King of the Mountain achievement data



32
# File 'lib/strava/models/xoms.rb', line 32

property 'kom'

#overallString, ...

Note:

Not documented by Strava API

Returns Overall segment record data.

Returns:

  • (String, Integer, nil)

    Overall segment record data



40
# File 'lib/strava/models/xoms.rb', line 40

property 'overall'

#qomString, ...

Note:

Not documented by Strava API

Returns Queen of the Mountain achievement data.

Returns:

  • (String, Integer, nil)

    Queen of the Mountain achievement data



36
# File 'lib/strava/models/xoms.rb', line 36

property 'qom'