Module: Strava::Api::Endpoints::Clubs
- Included in:
- Client
- Defined in:
- lib/strava/api/endpoints/clubs.rb
Overview
API endpoints for Strava clubs.
Clubs represent groups of athletes on Strava. Club API endpoints allow you to retrieve club information and view recent club events.
Note: the Club Activities, Club Members, and Club Admins endpoints were removed by Strava on September 1, 2026.
Instance Method Summary collapse
-
#athlete_clubs(options = {}, &block) ⇒ Object
List logged-in athlete clubs.
-
#club(id_or_options, options = {}) ⇒ Object
Get club.
-
#club_events(id_or_options, options = {}, &block) ⇒ Object
List club / group events.
Instance Method Details
#athlete_clubs(options = {}, &block) ⇒ Object
List logged-in athlete clubs.
27 28 29 |
# File 'lib/strava/api/endpoints/clubs.rb', line 27 def athlete_clubs( = {}, &block) paginate 'athlete/clubs', , Strava::Models::SummaryClub, &block end |
#club(id_or_options, options = {}) ⇒ Object
Get club.
37 38 39 40 |
# File 'lib/strava/api/endpoints/clubs.rb', line 37 def club(, = {}) id, = parse_args(, ) Strava::Models::DetailedClub.new(get("clubs/#{id}", )) end |