Module: Strava::Api::Endpoints::Uploads
- Included in:
- Client
- Defined in:
- lib/strava/api/endpoints/uploads.rb
Overview
API endpoints for Strava uploads.
Uploads allow you to create activities by uploading activity files in various formats such as FIT, TCX, and GPX. After uploading, the file is processed asynchronously and you can check the upload status to determine when the activity has been created.
Instance Method Summary collapse
-
#create_upload(options = {}) ⇒ Object
Uploads a new data file to create an activity from.
-
#upload(id_or_options, options = {}) ⇒ Object
Returns an upload for a given identifier.