Module: Strava::Api::Endpoints::Uploads
- Included in:
- Client
- Defined in:
- lib/strava/api/endpoints/uploads.rb
Instance Method Summary collapse
-
#create_upload(options = {}) ⇒ Object
Uploads a new data file to create an activity from.
-
#upload(id_or_options, options = {}) ⇒ Object
Returns an upload for a given identifier.
Instance Method Details
#create_upload(options = {}) ⇒ Object
Uploads a new data file to create an activity from.
25 26 27 |
# File 'lib/strava/api/endpoints/uploads.rb', line 25 def create_upload( = {}) Strava::Models::Upload.new(post('uploads', )) end |
#upload(id_or_options, options = {}) ⇒ Object
Returns an upload for a given identifier.
35 36 37 38 |
# File 'lib/strava/api/endpoints/uploads.rb', line 35 def upload(, = {}) id, = parse_args(, ) Strava::Models::Upload.new(get("uploads/#{id}", )) end |