Class: Strava::Models::BaseStream
- Inherits:
-
Response
- Object
- Hashie::Trash
- Strava::Model
- Response
- Strava::Models::BaseStream
- Defined in:
- lib/strava/models/base_stream.rb
Overview
Represents base stream metadata from the Strava API.
Streams are time-series data for activities such as GPS coordinates, heart rate, power, cadence, etc. The BaseStream provides metadata about how the stream data was sampled and processed.
Instance Method Summary collapse
-
#original_size ⇒ Integer
Total number of data points in the original stream before any resampling.
-
#resolution ⇒ String
Resolution of the stream data ("low", "medium", or "high").
-
#series_type ⇒ String
Type of series - how data points are indexed ("time" or "distance").
Instance Method Details
#original_size ⇒ Integer
Returns Total number of data points in the original stream before any resampling.
24 |
# File 'lib/strava/models/base_stream.rb', line 24 property 'original_size' |
#resolution ⇒ String
Returns Resolution of the stream data ("low", "medium", or "high").
27 |
# File 'lib/strava/models/base_stream.rb', line 27 property 'resolution' |
#series_type ⇒ String
Returns Type of series - how data points are indexed ("time" or "distance").
30 |
# File 'lib/strava/models/base_stream.rb', line 30 property 'series_type' |