Class: Strava::Models::Comment
- Inherits:
-
Response
- Object
- Hashie::Trash
- Strava::Model
- Response
- Strava::Models::Comment
- Defined in:
- lib/strava/models/comment.rb
Overview
Represents a comment on a Strava activity.
Comments are text messages left by athletes on activities. Each comment includes the text content, the athlete who made the comment, and timestamp.
Instance Method Summary collapse
-
#activity_id ⇒ Integer
ID of the activity this comment is on.
-
#athlete ⇒ SummaryAthlete
The athlete who made the comment.
-
#created_at ⇒ Time
When the comment was created.
-
#has_reacted ⇒ Boolean?
Whether the authenticated athlete has reacted to this comment.
-
#id ⇒ Integer
Comment ID.
-
#mentions_metadata ⇒ Hash?
Metadata about @mentions in the comment.
-
#post_id ⇒ Integer?
Associated post ID.
-
#reaction_count ⇒ Integer?
Number of reactions on this comment.
-
#resource_state ⇒ Integer?
Resource state indicator.
-
#text ⇒ String
The comment text.
Instance Method Details
#activity_id ⇒ Integer
Returns ID of the activity this comment is on.
25 |
# File 'lib/strava/models/comment.rb', line 25 property 'activity_id' |
#athlete ⇒ SummaryAthlete
Returns The athlete who made the comment.
34 |
# File 'lib/strava/models/comment.rb', line 34 property 'athlete', transform_with: ->(v) { Strava::Models::SummaryAthlete.new(v) } |
#created_at ⇒ Time
Returns When the comment was created.
31 |
# File 'lib/strava/models/comment.rb', line 31 property 'created_at', transform_with: ->(v) { Time.parse(v) } |
#has_reacted ⇒ Boolean?
Undocumented in official API
Returns Whether the authenticated athlete has reacted to this comment.
54 |
# File 'lib/strava/models/comment.rb', line 54 property 'has_reacted' |
#id ⇒ Integer
Returns Comment ID.
22 |
# File 'lib/strava/models/comment.rb', line 22 property 'id' |
#mentions_metadata ⇒ Hash?
Undocumented in official API
Returns Metadata about @mentions in the comment.
46 |
# File 'lib/strava/models/comment.rb', line 46 property 'mentions_metadata' |
#post_id ⇒ Integer?
Undocumented in official API
Returns Associated post ID.
38 |
# File 'lib/strava/models/comment.rb', line 38 property 'post_id' |
#reaction_count ⇒ Integer?
Undocumented in official API
Returns Number of reactions on this comment.
50 |
# File 'lib/strava/models/comment.rb', line 50 property 'reaction_count' |
#resource_state ⇒ Integer?
Undocumented in official API
Returns Resource state indicator.
42 |
# File 'lib/strava/models/comment.rb', line 42 property 'resource_state' |
#text ⇒ String
Returns The comment text.
28 |
# File 'lib/strava/models/comment.rb', line 28 property 'text' |