Class: Strava::Models::Kudoser
- Inherits:
-
Response
- Object
- Hashie::Trash
- Strava::Model
- Response
- Strava::Models::Kudoser
- Defined in:
- lib/strava/models/kudoser.rb
Overview
Note:
This model is not documented by Strava API documentation. Properties are inferred from API responses.
Represents a user who gave kudos to an activity.
Kudos are a way for athletes to show appreciation for each other's activities. This model is not documented in the official Strava API reference.
Instance Method Summary collapse
-
#avatar_url ⇒ String?
URL to the athlete's avatar image.
-
#destination_url ⇒ String?
URL to the athlete's profile page.
-
#display_name ⇒ String?
Display name of the athlete who gave kudos.
-
#show_name ⇒ Boolean?
Whether to show the athlete's name.
Instance Method Details
#avatar_url ⇒ String?
Note:
Not documented by Strava API
Returns URL to the athlete's avatar image.
34 |
# File 'lib/strava/models/kudoser.rb', line 34 property 'avatar_url' |
#destination_url ⇒ String?
Note:
Not documented by Strava API
Returns URL to the athlete's profile page.
26 |
# File 'lib/strava/models/kudoser.rb', line 26 property 'destination_url' |
#display_name ⇒ String?
Note:
Not documented by Strava API
Returns Display name of the athlete who gave kudos.
30 |
# File 'lib/strava/models/kudoser.rb', line 30 property 'display_name' |
#show_name ⇒ Boolean?
Note:
Not documented by Strava API
Returns Whether to show the athlete's name.
38 |
# File 'lib/strava/models/kudoser.rb', line 38 property 'show_name' |