Class: Strava::Models::LocalLegend
- Inherits:
-
Response
- Object
- Hashie::Trash
- Strava::Model
- Response
- Strava::Models::LocalLegend
- Defined in:
- lib/strava/models/local_legend.rb
Overview
This model is not documented by Strava API documentation. Properties are inferred from API responses.
Represents Local Legend status on a segment.
Local Legends are athletes with the most efforts on a segment in the last 90 days. This model contains information about the current local legend for a segment. This model is not documented in the official Strava API reference.
Instance Method Summary collapse
-
#athlete_id ⇒ Integer?
ID of the athlete who is the local legend.
-
#destination ⇒ Destination?
Link to related resource.
-
#effort_count ⇒ Integer?
Number of efforts by this athlete in the qualifying period.
-
#effort_counts ⇒ Hash?
Detailed effort count data.
-
#effort_description ⇒ String?
Description of the effort count (e.g., "X efforts in the last 90 days").
-
#profile ⇒ String?
URL to the athlete's profile picture.
-
#title ⇒ String?
Title or name of the local legend.
Instance Method Details
#athlete_id ⇒ Integer?
Not documented by Strava API
Returns ID of the athlete who is the local legend.
29 |
# File 'lib/strava/models/local_legend.rb', line 29 property 'athlete_id' |
#destination ⇒ Destination?
Not documented by Strava API
Returns Link to related resource.
53 |
# File 'lib/strava/models/local_legend.rb', line 53 property 'destination' |
#effort_count ⇒ Integer?
Not documented by Strava API
Returns Number of efforts by this athlete in the qualifying period.
45 |
# File 'lib/strava/models/local_legend.rb', line 45 property 'effort_count' |
#effort_counts ⇒ Hash?
Not documented by Strava API
Returns Detailed effort count data.
49 |
# File 'lib/strava/models/local_legend.rb', line 49 property 'effort_counts' |
#effort_description ⇒ String?
Not documented by Strava API
Returns Description of the effort count (e.g., "X efforts in the last 90 days").
41 |
# File 'lib/strava/models/local_legend.rb', line 41 property 'effort_description' |
#profile ⇒ String?
Not documented by Strava API
Returns URL to the athlete's profile picture.
37 |
# File 'lib/strava/models/local_legend.rb', line 37 property 'profile' |
#title ⇒ String?
Not documented by Strava API
Returns Title or name of the local legend.
33 |
# File 'lib/strava/models/local_legend.rb', line 33 property 'title' |