Class: Strava::Models::Map
- Inherits:
-
Response
- Object
- Hashie::Trash
- Strava::Model
- Response
- Strava::Models::Map
- Defined in:
- lib/strava/models/map.rb
Overview
Represents a map with polyline data for an activity, route, or segment.
Maps contain encoded polyline data that represents the geographic path. The polyline format uses Google's encoded polyline algorithm which can be decoded using libraries like the 'polylines' gem.
Instance Method Summary collapse
-
#id ⇒ String
Map identifier.
-
#polyline ⇒ String
Google polyline encoding of the route (higher resolution).
-
#resource_state ⇒ Integer
Resource state indicator.
-
#summary_polyline ⇒ String
Google polyline encoding of the route (lower resolution).
Instance Method Details
#id ⇒ String
Returns Map identifier.
31 |
# File 'lib/strava/models/map.rb', line 31 property 'id' |
#polyline ⇒ String
Returns Google polyline encoding of the route (higher resolution).
40 |
# File 'lib/strava/models/map.rb', line 40 property 'polyline' |
#resource_state ⇒ Integer
Returns Resource state indicator.
37 |
# File 'lib/strava/models/map.rb', line 37 property 'resource_state' |
#summary_polyline ⇒ String
Returns Google polyline encoding of the route (lower resolution).
34 |
# File 'lib/strava/models/map.rb', line 34 property 'summary_polyline' |