Module: Strava::Models::Mixins::EstimatedMovingTime
- Extended by:
- ActiveSupport::Concern
- Includes:
- TimeInHours
- Included in:
- Route
- Defined in:
- lib/strava/models/mixins/estimated_moving_time.rb
Overview
Provides estimated moving time formatting methods.
Estimated moving time is Strava's prediction of how long it will take to complete a route based on distance, elevation, and typical speeds. This is commonly used for routes.
Instance Method Summary collapse
-
#estimated_moving_time_in_hours_s ⇒ String?
Returns formatted estimated moving time as hours, minutes, and seconds.
Instance Method Details
#estimated_moving_time_in_hours_s ⇒ String?
Returns formatted estimated moving time as hours, minutes, and seconds.
32 33 34 |
# File 'lib/strava/models/mixins/estimated_moving_time.rb', line 32 def estimated_moving_time_in_hours_s time_in_hours_s estimated_moving_time end |