Class: Strava::Models::PhotosSummary
- Inherits:
-
Response
- Object
- Hashie::Trash
- Strava::Model
- Response
- Strava::Models::PhotosSummary
- Defined in:
- lib/strava/models/photos_summary.rb
Overview
Represents summary photo information for an activity.
Contains basic information about photos attached to an activity, including the count and primary photo reference.
Instance Method Summary collapse
-
#count ⇒ Integer
Total number of photos attached to the activity.
-
#primary ⇒ PhotosSummaryPrimary?
The primary/featured photo reference.
-
#use_primary_photo ⇒ Boolean?
Whether to use the primary photo for display.
Instance Method Details
#count ⇒ Integer
Returns Total number of photos attached to the activity.
26 |
# File 'lib/strava/models/photos_summary.rb', line 26 property 'count' |
#primary ⇒ PhotosSummaryPrimary?
Returns The primary/featured photo reference.
33 |
# File 'lib/strava/models/photos_summary.rb', line 33 property 'primary', transform_with: ->(v) { Strava::Models::PhotosSummaryPrimary.new(v) } |
#use_primary_photo ⇒ Boolean?
Note:
Not documented by Strava API
Returns Whether to use the primary photo for display.
30 |
# File 'lib/strava/models/photos_summary.rb', line 30 property 'use_primary_photo' |