Class: Strava::Models::PhotosSummaryPrimary
- Inherits:
-
Response
- Object
- Hashie::Trash
- Strava::Model
- Response
- Strava::Models::PhotosSummaryPrimary
- Defined in:
- lib/strava/models/photos_summary_primary.rb
Overview
Represents the primary photo reference in a photos summary.
Contains identification and URL information for the primary photo of an activity.
Instance Method Summary collapse
-
#id ⇒ Integer?
Unique identifier for the photo.
-
#media_type ⇒ Integer?
Type of media (1=photo, 2=video).
-
#source ⇒ Integer
Source of the photo (1=native Strava upload, 2=Instagram).
-
#unique_id ⇒ String
Unique identifier string for the photo.
-
#urls ⇒ Hash
Hash containing URLs to different sizes of the photo.
Instance Method Details
#id ⇒ Integer?
Returns Unique identifier for the photo.
25 |
# File 'lib/strava/models/photos_summary_primary.rb', line 25 property 'id' |
#media_type ⇒ Integer?
Note:
Not documented by Strava API
Returns Type of media (1=photo, 2=video).
38 |
# File 'lib/strava/models/photos_summary_primary.rb', line 38 property 'media_type' |
#source ⇒ Integer
Returns Source of the photo (1=native Strava upload, 2=Instagram).
28 |
# File 'lib/strava/models/photos_summary_primary.rb', line 28 property 'source' |
#unique_id ⇒ String
Returns Unique identifier string for the photo.
31 |
# File 'lib/strava/models/photos_summary_primary.rb', line 31 property 'unique_id' |
#urls ⇒ Hash
Returns Hash containing URLs to different sizes of the photo.
34 |
# File 'lib/strava/models/photos_summary_primary.rb', line 34 property 'urls' |