Class: Strava::Models::SummaryPRSegmentEffort
- Inherits:
-
Response
- Object
- Hashie::Trash
- Strava::Model
- Response
- Strava::Models::SummaryPRSegmentEffort
- Defined in:
- lib/strava/models/summary_pr_segment_effort.rb
Overview
Represents an athlete's personal record (PR) on a segment.
Contains information about the athlete's best effort on a particular segment, including when it was achieved and how many times they've attempted the segment.
Instance Method Summary collapse
-
#effort_count ⇒ Integer
Total number of times the athlete has attempted this segment.
-
#pr_activity_id ⇒ Integer?
Activity ID where the PR was achieved.
-
#pr_activity_visibility ⇒ String?
Visibility setting for the activity containing the PR.
-
#pr_date ⇒ Date?
Date when the PR was set.
-
#pr_elapsed_time ⇒ Integer?
Elapsed time for the PR effort in seconds.
-
#pr_visibility ⇒ String?
Visibility setting for the PR effort.
Instance Method Details
#effort_count ⇒ Integer
Returns Total number of times the athlete has attempted this segment.
35 |
# File 'lib/strava/models/summary_pr_segment_effort.rb', line 35 property 'effort_count' |
#pr_activity_id ⇒ Integer?
Returns Activity ID where the PR was achieved.
26 |
# File 'lib/strava/models/summary_pr_segment_effort.rb', line 26 property 'pr_activity_id' |
#pr_activity_visibility ⇒ String?
Not documented by Strava API
Returns Visibility setting for the activity containing the PR.
43 |
# File 'lib/strava/models/summary_pr_segment_effort.rb', line 43 property 'pr_activity_visibility' |
#pr_date ⇒ Date?
Returns Date when the PR was set.
32 |
# File 'lib/strava/models/summary_pr_segment_effort.rb', line 32 property 'pr_date', transform_with: ->(v) { Date.parse(v) } |
#pr_elapsed_time ⇒ Integer?
Returns Elapsed time for the PR effort in seconds.
29 |
# File 'lib/strava/models/summary_pr_segment_effort.rb', line 29 property 'pr_elapsed_time' |
#pr_visibility ⇒ String?
Not documented by Strava API
Returns Visibility setting for the PR effort.
39 |
# File 'lib/strava/models/summary_pr_segment_effort.rb', line 39 property 'pr_visibility' |