Class: Strava::Models::UpdatableActivity
- Inherits:
-
Response
- Object
- Hashie::Trash
- Strava::Model
- Response
- Strava::Models::UpdatableActivity
- Defined in:
- lib/strava/models/updatable_activity.rb
Overview
Represents the response from updating an activity.
When you update an activity using the update_activity endpoint, Strava returns this model containing the fields that were successfully updated. This is a subset of the full activity data.
Instance Method Summary collapse
-
#commute ⇒ Boolean?
Whether this activity is a commute.
-
#description ⇒ String?
Description of the activity.
-
#gear_id ⇒ String?
ID of the gear (shoes/bike) used for this activity.
-
#hide_from_home ⇒ Boolean?
Whether to hide this activity from the home feed.
-
#name ⇒ String?
Name/title of the activity.
-
#sport_type ⇒ String?
Sport type (e.g., "Run", "Ride", "Swim").
-
#trainer ⇒ Boolean?
Whether this activity was done on a trainer/treadmill.
Instance Method Details
#commute ⇒ Boolean?
Returns Whether this activity is a commute.
30 |
# File 'lib/strava/models/updatable_activity.rb', line 30 property 'commute' |
#description ⇒ String?
Returns Description of the activity.
39 |
# File 'lib/strava/models/updatable_activity.rb', line 39 property 'description' |
#gear_id ⇒ String?
Returns ID of the gear (shoes/bike) used for this activity.
48 |
# File 'lib/strava/models/updatable_activity.rb', line 48 property 'gear_id' |
#hide_from_home ⇒ Boolean?
Returns Whether to hide this activity from the home feed.
36 |
# File 'lib/strava/models/updatable_activity.rb', line 36 property 'hide_from_home' |
#name ⇒ String?
Returns Name/title of the activity.
42 |
# File 'lib/strava/models/updatable_activity.rb', line 42 property 'name' |
#sport_type ⇒ String?
Returns Sport type (e.g., "Run", "Ride", "Swim").
45 |
# File 'lib/strava/models/updatable_activity.rb', line 45 property 'sport_type' |
#trainer ⇒ Boolean?
Returns Whether this activity was done on a trainer/treadmill.
33 |
# File 'lib/strava/models/updatable_activity.rb', line 33 property 'trainer' |