Class: Strava::Models::Xoms
- Inherits:
-
Response
- Object
- Hashie::Trash
- Strava::Model
- Response
- Strava::Models::Xoms
- Defined in:
- lib/strava/models/xoms.rb
Overview
This model is not documented by Strava API documentation. Properties are inferred from API responses.
Represents segment leaderboard achievements (KOM/QOM).
Contains information about King of the Mountain (KOM), Queen of the Mountain (QOM), and overall segment records. This model is not documented in the official Strava API reference.
Instance Method Summary collapse
-
#destination ⇒ Destination?
Link to the segment where this achievement was earned.
-
#kom ⇒ String, ...
King of the Mountain achievement data.
-
#overall ⇒ String, ...
Overall segment record data.
-
#qom ⇒ String, ...
Queen of the Mountain achievement data.
Instance Method Details
#destination ⇒ Destination?
Not documented by Strava API
Returns Link to the segment where this achievement was earned.
44 |
# File 'lib/strava/models/xoms.rb', line 44 property 'destination', transform_with: ->(v) { Strava::Models::Destination.new(v) } |
#kom ⇒ String, ...
Not documented by Strava API
Returns King of the Mountain achievement data.
32 |
# File 'lib/strava/models/xoms.rb', line 32 property 'kom' |
#overall ⇒ String, ...
Not documented by Strava API
Returns Overall segment record data.
40 |
# File 'lib/strava/models/xoms.rb', line 40 property 'overall' |
#qom ⇒ String, ...
Not documented by Strava API
Returns Queen of the Mountain achievement data.
36 |
# File 'lib/strava/models/xoms.rb', line 36 property 'qom' |